@@ -47,7 +47,9 @@ def _require(tkroot):
             tkdnd_platform_rep = "linux-arm64"
         elif platform.system()=="Linux" and platform.machine()=="x86_64":
             tkdnd_platform_rep = "linux-x64"
-        elif platform.system()=="Windows":
+        elif platform.system()=="Windows" and platform.machine()=="arm64":
+            tkdnd_platform_rep = "win-arm64"
+        elif platform.system()=="Windows" and platform.machine()=="amd64":
             tkdnd_platform_rep = "win-x64"
         else:
             raise RuntimeError('Plaform not supported.')
